@@ -92,7 +92,7 @@
 #'
 #' @author Johannes Koch
 #' @export
-#' 
+#'
 interfaceplot <- function(x = ".",
                           modules_to_include = NULL,
                           modules_to_exclude = NULL,
@@ -100,7 +100,7 @@ interfaceplot <- function(x = ".",
                           links_to_exclude = NULL,
                           items_to_include = NULL,
                           items_to_exclude = NULL,
-                          items_to_display = NULL, 
+                          items_to_display = NULL,
                           default_groups = list(default1 = list(name = "core",
                                                                 nodes = "core",
                                                                 color = "black",
@@ -115,13 +115,13 @@ interfaceplot <- function(x = ".",
                           max_num_edge_labels = NULL,
                           max_num_nodes_for_edge_labels = 30,
                           ...) {
-  
+
   # STEP 1: Get the interface info of model. At the end, the info will take the shape of an
   # edge list for qqgraph
   ########################################################################################
   # Perform codeCheck if necessary, to get module interface info
-  if(is.character(x)) x <- codeCheck(x, "modules")  
-  
+  if(is.character(x)) x <- codeCheck(x, "modules")
+
   # Store the interface info in a clear way:
   # 1 column = string with start module
   # 2 column = string with end module
@@ -134,93 +134,93 @@ interfaceplot <- function(x = ".",
                          x[[i]][names(x[[i]])=="in"])
       if (length(items) != "0") {
         interface_info <- bind_rows(interface_info,
-                                    tibble("from"=o, 
-                                           "to"=i, 
-                                           "num_items"=length(items), 
+                                    tibble("from"=o,
+                                           "to"=i,
+                                           "num_items"=length(items),
                                            "items"=paste(items, collapse=" ")))
-        
+
       }
     }
   }
   ########################################################################################
-  
-  
-  
-  
-  # STEP 2: Filter the interface_info 
+
+
+
+
+  # STEP 2: Filter the interface_info
   ########################################################################################
   # Filter by module
   if(!is.null(modules_to_include)){
-    interface_info <- interface_info %>% 
+    interface_info <- interface_info %>%
       filter(.data$from %in% modules_to_include | .data$to %in% modules_to_include)
   }
   if(!is.null(modules_to_exclude)){
-    interface_info <- interface_info %>% 
+    interface_info <- interface_info %>%
       filter(!(.data$from %in% modules_to_exclude | .data$to %in% modules_to_exclude))
   }
   # Filter by link
   if(!is.null(links_to_include)){
-    interface_info <- interface_info %>% 
+    interface_info <- interface_info %>%
       filter(apply(sapply(links_to_include, function(y) .data$from %in% y$from & .data$to %in% y$to),1,any))
   }
   if(!is.null(links_to_exclude)){
-    interface_info <- interface_info %>% 
+    interface_info <- interface_info %>%
       filter(apply(sapply(links_to_exclude, function(y) !(.data$from %in% y$from & .data$to %in% y$to)),1,all))
   }
-  # Filter by item 
+  # Filter by item
   if(!is.null(items_to_include)){
-    my_regex <- paste0(items_to_include, collapse ="|") 
-    interface_info$items <- interface_info %>% 
+    my_regex <- paste0(items_to_include, collapse ="|")
+    interface_info$items <- interface_info %>%
       select(items) %>%
       apply(1, str_extract_all, my_regex, simplify = TRUE) %>%
       sapply(paste, collapse=" ")
     interface_info <- filter(interface_info, items != "")
-  } 
+  }
   if(!is.null(items_to_exclude)){
-    my_regex <- paste0(items_to_exclude, collapse ="|") 
-    interface_info <- interface_info %>% 
+    my_regex <- paste0(items_to_exclude, collapse ="|")
+    interface_info <- interface_info %>%
       mutate(items = str_remove_all(items, pattern = my_regex)) %>%
       filter(items != "")
   }
-  
+
   # Filter in case "highlight_groups$edges_to_ignore" is not NULL for any highlight group
   if (any(sapply(highlight_groups, function(y) !is.null(y$edges_to_ignore)))) {
     # Add column link_to_keep and set to FALSE for all...
     interface_info <- interface_info %>% mutate(link_to_keep = FALSE)
-    
+
     for (hl in highlight_groups) {
       # ... and now set to TRUE the links the links we actually want to keep
       if (!is.null(hl$edges_to_ignore)) {
         if (hl$edges_to_ignore == "outside") {
-          interface_info <- interface_info %>% 
-            mutate(link_to_keep = if_else(.data$to %in% hl$nodes | .data$from %in% hl$nodes, 
+          interface_info <- interface_info %>%
+            mutate(link_to_keep = if_else(.data$to %in% hl$nodes | .data$from %in% hl$nodes,
                                           TRUE,
                                           .data$link_to_keep))
         }
         if (hl$edges_to_ignore == "incoming") {
-          interface_info <- interface_info %>% 
+          interface_info <- interface_info %>%
             mutate(link_to_keep = if_else(.data$from %in% hl$nodes, TRUE, .data$link_to_keep))
         }
         if (hl$edges_to_ignore == "outgoing") {
-          interface_info <- interface_info %>% 
+          interface_info <- interface_info %>%
             mutate(link_to_keep = if_else(.data$to %in% hl$nodes, TRUE, .data$link_to_keep))
         }
         if (hl$edges_to_ignore == "outgoing_to_noReturn") {
-          outside_nodes_that_give_input <- interface_info %>% 
+          outside_nodes_that_give_input <- interface_info %>%
             filter(!.data$from %in% hl$nodes & .data$to %in% hl$nodes) %>%
-            select(.data$from)  %>% unlist() %>% unique()
-          
-          interface_info <- interface_info %>% 
-            mutate(link_to_keep = if_else(.data$to %in% hl$nodes | 
-                                            (.data$from %in% hl$nodes & .data$to %in% outside_nodes_that_give_input), 
+            select('from')  %>% unlist() %>% unique()
+
+          interface_info <- interface_info %>%
+            mutate(link_to_keep = if_else(.data$to %in% hl$nodes |
+                                            (.data$from %in% hl$nodes & .data$to %in% outside_nodes_that_give_input),
                                           TRUE, .data$link_to_keep))
         }
       }
-      
+
     }
-    interface_info <- interface_info %>% filter(.data$link_to_keep==TRUE) %>% select(-.data$link_to_keep)
+    interface_info <- interface_info %>% filter(.data$link_to_keep==TRUE) %>% select(-'link_to_keep')
   }
-  
+
   # Check that there is something left
   if(dim(interface_info)[1]==0) {
     warning("Nothing to plot anymore after filters have been applied!")
@@ -231,25 +231,25 @@ interfaceplot <- function(x = ".",
     return(interface_info)
   }
   ########################################################################################
-  
-  
-  
+
+
+
   # STEP 3: Save edge list now, and define some variables for defining the plot_options
   ########################################################################################
   # Save the interface into without items as the weighted edge list to be passed to qgrpah
   edge_list <- select(interface_info, -items)
-  
+
   # Define some usefull variables
-  node_names <- interface_info %>% select(.data$from, .data$to) %>% unlist() %>% unique()
+  node_names <- interface_info %>% select('from', 'to') %>% unlist() %>% unique()
   num_nodes <- length(node_names)
-  edge_names <- interface_info %>% select(.data$from) %>% unlist()
+  edge_names <- interface_info %>% select('from') %>% unlist()
   num_edges <- length(edge_names)
   default_shape <- "ellipse"
   default_color <- "#6c9ebf"
   ########################################################################################
-  
-  
-  
+
+
+
   # STEP 4: Assign nodes to groups. A node can only be assigned to one group!
   ########################################################################################
   my_groups <- list(name=NULL,
@@ -257,79 +257,79 @@ interfaceplot <- function(x = ".",
                     shape=NULL,
                     modules=NULL,
                     assignments=NULL)
-  
+
   nodes_left_to_assign <- node_names
-  
+
   # Start with the highlight groups, if they exist.
   if (!is.null(highlight_groups)) {
     for (hlgr in highlight_groups) {
       if (rlang::is_empty(nodes_left_to_assign)) break
-      
+
       my_groups$name <- c(my_groups$name, hlgr$name)
       my_groups$color <- c(my_groups$color, hlgr$color)
       my_groups$shape <- c(my_groups$shape, hlgr$shape)
-      
+
       my_groups$nodes[hlgr$name] <- list(nodes_left_to_assign[nodes_left_to_assign%in%hlgr$nodes])
       my_groups$assignments[hlgr$name] <- list(which(node_names%in%hlgr$nodes))
       nodes_left_to_assign <- nodes_left_to_assign[!nodes_left_to_assign%in%hlgr$nodes]
     }
   }
 
-  # Assign modules that are left, to the default groups 
+  # Assign modules that are left, to the default groups
   for (dfgr in default_groups) {
     if (rlang::is_empty(nodes_left_to_assign)) break
-    
+
     if (!is.null(dfgr$nodes) && any(dfgr$nodes %in% nodes_left_to_assign)) {
       my_groups$name <- c(my_groups$name, dfgr$name)
       my_groups$color <- c(my_groups$color, dfgr$color)
       my_groups$shape <- c(my_groups$shape, dfgr$shape)
-      
+
       my_groups$nodes[dfgr$name] <- list(nodes_left_to_assign[nodes_left_to_assign%in%dfgr$nodes])
       my_groups$assignments[dfgr$name]<- list(which(node_names%in%dfgr$nodes))
-      
+
       nodes_left_to_assign <- nodes_left_to_assign[!nodes_left_to_assign%in%dfgr$nodes]
-    } 
+    }
     if (is.null(dfgr$nodes)) {
       my_groups$name <- c(my_groups$name, dfgr$name)
       my_groups$color <- c(my_groups$color, dfgr$color)
       my_groups$shape <- c(my_groups$shape, dfgr$shape)
-      
+
       my_groups$nodes[dfgr$name] <-list(nodes_left_to_assign)
       my_groups$assignments[dfgr$name] <- list(which(node_names%in%nodes_left_to_assign))
     }
   }
   ########################################################################################
-  
-  
-  
+
+
+
   # STEP 5: Prepare qgraph parameters: content
   ########################################################################################
   # Group assignements
   group_assignments <- my_groups$assignments
-  
+
   # Node shape: one shape per node depending on group
   shape_nodes <- rep(" ", each=num_nodes)
   names(shape_nodes) <- node_names
   for (gr in 1:length(my_groups$name)) {
     shape_nodes[my_groups$nodes[[gr]]] <- my_groups$shape[gr]
   }
-  
+
   # Node color: one color per group
   col_nodes <- my_groups$color
 
   # Edge color: one color per edge
   col_edges <- rep(default_groups$default2$color, each=num_edges)
   names(col_edges) <- edge_names
-  
+
   # Apply edge color highlights
   if (!is.null(highlight_groups)) {
     for (hl in highlight_groups) {
       if (!is.null(hl$edges_to_highlight)) {
-        # Highlight DEPARTING and INCOMING edges 
+        # Highlight DEPARTING and INCOMING edges
         if (hl$edges_to_highlight == "all") {
           col_edges[interface_info$from %in% hl$nodes | interface_info$to %in% hl$nodes] <- hl$color
         }
-        # Highlight DEPARTING edges 
+        # Highlight DEPARTING edges
         if (hl$edges_to_highlight == "outgoing") {
           col_edges[interface_info$from %in% hl$nodes] <- hl$color
         }
@@ -344,25 +344,25 @@ interfaceplot <- function(x = ".",
       }
     }
   }
-  
-  
+
+
   # Edge labels
   if(is.null(items_to_display)) {
     lab_edges <- list()
   } else {
-    my_regex <- paste0(items_to_display, collapse ="|") 
+    my_regex <- paste0(items_to_display, collapse ="|")
 
-    lab_edges <- interface_info %>% 
-      pull(items) %>% 
-      as.list() %>% 
+    lab_edges <- interface_info %>%
+      pull(items) %>%
+      as.list() %>%
       lapply(str_extract_all, my_regex, simplify=T) %>%
-      lapply(paste, collapse="\n") %>% 
+      lapply(paste, collapse="\n") %>%
       unlist()
-    
+
     if (all(lab_edges=="")) lab_edges <- list()
   }
-  
-  
+
+
   # Special case when the groups all consits of single modules!!
   if (all(sapply(my_groups$nodes, length)==1)) {
 
@@ -377,22 +377,22 @@ interfaceplot <- function(x = ".",
     for (gr in 1:length(my_groups$name)) {
       col_nodes[my_groups$nodes[[gr]]] <- my_groups$color[gr]
     }
-    
+
     if (add_nodeName_legend) {
       message("Groups will not be shown in the legend, since they are all composed of a single node.")
       add_nodeName_legend <- FALSE
     }
   }
   ########################################################################################
-  
-  
-  
+
+
+
   # STEP 6: Prepare qgraph parameters: graphics
-  ########################################################################################  
-  # Shorten module names to max_length_node_names to fit into plot 
+  ########################################################################################
+  # Shorten module names to max_length_node_names to fit into plot
   if (!is.null(max_length_node_names)) {
     n <- max_length_node_names
-    
+
     # Make sure that nodes don't have the same name after cut!
     check_n <- function(y,n) {
       z <- str_trunc(y, n, ellipsis=".")
@@ -401,7 +401,7 @@ interfaceplot <- function(x = ".",
       } else {
         message(paste0("Couldn't truncate node names after ", n, " letters (would have resulted in duplicate names)... "))
         while (any(duplicated(z))) {
-          n <- n + 1 
+          n <- n + 1
           z <- str_trunc(y, n, ellipsis=".")
         }
         message(paste0("truncating after ", n, " letters instead."))
@@ -409,16 +409,16 @@ interfaceplot <- function(x = ".",
       return(n)
     }
     n <- check_n(node_names, n)
-    
-    edge_list <- interface_info %>% 
+
+    edge_list <- interface_info %>%
       mutate(from = stringr::str_trunc(.data$from, n, ellipsis = "."),
              to = stringr::str_trunc(.data$to, n, ellipsis = ".")) %>%
       select(-items)
-  
+
     names(shape_nodes) <- stringr::str_trunc(names(shape_nodes), n, ellipsis=".")
     names(col_edges) <- stringr::str_trunc(names(col_edges), n, ellipsis=".")
   }
-  
+
   # Shorten item lists on edge lables
   if (!rlang::is_empty(lab_edges) && !is.null(max_num_edge_labels)) {
     if (max_num_edge_labels == "adjust") {
@@ -433,16 +433,16 @@ interfaceplot <- function(x = ".",
       my_regex2 <- paste0("^.*[^\\n]", paste0(rep("\\n[^\\n]*", n-1), collapse = ""))
       lab_edges <- if_else(!is.na(str_extract(lab_edges, my_regex1)),
                            paste0(str_extract(lab_edges, my_regex2), "\n(...)"),
-                           lab_edges) 
+                           lab_edges)
       my_title <- "Long lists of interface items are abbreviated with '(...)'"
-    } 
+    }
   }
-  ########################################################################################  
-  
-  
+  ########################################################################################
+
+
 
   # STEP 7: Store all qgraph parameters in the "params" list and create graph
-  ######################################################################################## 
+  ########################################################################################
   params <- list(...)
   params$input <- edge_list
   params$edgelist <- TRUE
@@ -455,10 +455,10 @@ interfaceplot <- function(x = ".",
 
   # Add node name legend
   if (add_nodeName_legend) params$nodeNames <- node_names
-  
+
   # Set ratio of a and b alxis of the ellipses, if not already given by ...
   if (!"vsize2" %in% names(params)) params$vsize2 <- 2/3
-  
+
   # Edge labels, only displayed if the graph isn't to full of nodes!
   if (!rlang::is_empty(lab_edges)) {
     if (num_nodes <= max_num_nodes_for_edge_labels) {
@@ -466,23 +466,23 @@ interfaceplot <- function(x = ".",
       # Change some default edge.label parameters, if not already given by ...
       if (!"edge.label.position" %in% names(params)) params$edge.label.position <- 0.4
       if (!"edge.label.margin" %in% names(params)) params$edge.label.margin <- 0.02
-      if (!"edge.label.cex" %in% names(params)) params$edge.label.cex <- if_else(num_nodes<=9, 
-                                                                                 0.65, 
+      if (!"edge.label.cex" %in% names(params)) params$edge.label.cex <- if_else(num_nodes<=9,
+                                                                                 0.65,
                                                                                  0.65-0.05*(num_nodes-9))
       # Set fade to false if items edge labels are to be displayed, if not already given by ...
       if (!"fade" %in% names(params)) params$fade <- FALSE
     } else {
       my_title <- "Interface items are not shown due to lack of space..."
     }
-  } 
-  
+  }
+
   if (!"title" %in% names(params) && exists("my_title")) {
     params$title <- my_title
     params$title.cex <- 0.8
   }
-  
-  qgraphObject <- do.call(qgraph::qgraph, params) 
-  ######################################################################################## 
+
+  qgraphObject <- do.call(qgraph::qgraph, params)
+  ########################################################################################
 
   return(interface_info)
 }
